@@ -10,11 +10,19 @@ Usage::
     client: DataSyncClient = boto3.client("datasync")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_datasync.literals import (
+    ListAgentsPaginatorName,
+    ListLocationsPaginatorName,
+    ListTagsForResourcePaginatorName,
+    ListTaskExecutionsPaginatorName,
+    ListTasksPaginatorName,
+    ObjectStorageServerProtocol,
+    S3StorageClass,
+)
 from mypy_boto3_datasync.paginator import (
     ListAgentsPaginator,
     ListLocationsPaginator,
@@ -59,12 +67,6 @@ from mypy_boto3_datasync.type_defs import (
     TaskScheduleTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("DataSyncClient",)
 
 
@@ -84,7 +86,7 @@ class Exceptions:
 
 class DataSyncClient:
     """
-    [DataSync.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client)
+    [DataSync.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client)
     """
 
     meta: ClientMeta
@@ -92,12 +94,12 @@ class DataSyncClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.can_paginate)
         """
 
     def cancel_task_execution(self, TaskExecutionArn: str) -> Dict[str, Any]:
         """
-        [Client.cancel_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
+        [Client.cancel_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
         """
 
     def create_agent(
@@ -110,7 +112,7 @@ class DataSyncClient:
         SecurityGroupArns: List[str] = None,
     ) -> CreateAgentResponseTypeDef:
         """
-        [Client.create_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.create_agent)
+        [Client.create_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.create_agent)
         """
 
     def create_location_efs(
@@ -121,7 +123,7 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationEfsResponseTypeDef:
         """
-        [Client.create_location_efs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.create_location_efs)
+        [Client.create_location_efs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.create_location_efs)
         """
 
     def create_location_fsx_windows(
@@ -135,7 +137,7 @@ class DataSyncClient:
         Domain: str = None,
     ) -> CreateLocationFsxWindowsResponseTypeDef:
         """
-        [Client.create_location_fsx_windows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
+        [Client.create_location_fsx_windows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
         """
 
     def create_location_nfs(
@@ -147,7 +149,7 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationNfsResponseTypeDef:
         """
-        [Client.create_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.create_location_nfs)
+        [Client.create_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.create_location_nfs)
         """
 
     def create_location_object_storage(
@@ -156,14 +158,14 @@ class DataSyncClient:
         BucketName: str,
         AgentArns: List[str],
         ServerPort: int = None,
-        ServerProtocol: Literal["HTTPS", "HTTP"] = None,
+        ServerProtocol: ObjectStorageServerProtocol = None,
         Subdirectory: str = None,
         AccessKey: str = None,
         SecretKey: str = None,
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationObjectStorageResponseTypeDef:
         """
-        [Client.create_location_object_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
+        [Client.create_location_object_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
         """
 
     def create_location_s3(
@@ -171,20 +173,12 @@ class DataSyncClient:
         S3BucketArn: str,
         S3Config: "S3ConfigTypeDef",
         Subdirectory: str = None,
-        S3StorageClass: Literal[
-            "STANDARD",
-            "STANDARD_IA",
-            "ONEZONE_IA",
-            "INTELLIGENT_TIERING",
-            "GLACIER",
-            "DEEP_ARCHIVE",
-            "OUTPOSTS",
-        ] = None,
+        S3StorageClass: S3StorageClass = None,
         AgentArns: List[str] = None,
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationS3ResponseTypeDef:
         """
-        [Client.create_location_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.create_location_s3)
+        [Client.create_location_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.create_location_s3)
         """
 
     def create_location_smb(
@@ -199,7 +193,7 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateLocationSmbResponseTypeDef:
         """
-        [Client.create_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.create_location_smb)
+        [Client.create_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.create_location_smb)
         """
 
     def create_task(
@@ -214,73 +208,73 @@ class DataSyncClient:
         Tags: List["TagListEntryTypeDef"] = None,
     ) -> CreateTaskResponseTypeDef:
         """
-        [Client.create_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.create_task)
+        [Client.create_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.create_task)
         """
 
     def delete_agent(self, AgentArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.delete_agent)
+        [Client.delete_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.delete_agent)
         """
 
     def delete_location(self, LocationArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.delete_location)
+        [Client.delete_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.delete_location)
         """
 
     def delete_task(self, TaskArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.delete_task)
+        [Client.delete_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.delete_task)
         """
 
     def describe_agent(self, AgentArn: str) -> DescribeAgentResponseTypeDef:
         """
-        [Client.describe_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_agent)
+        [Client.describe_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_agent)
         """
 
     def describe_location_efs(self, LocationArn: str) -> DescribeLocationEfsResponseTypeDef:
         """
-        [Client.describe_location_efs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_location_efs)
+        [Client.describe_location_efs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_location_efs)
         """
 
     def describe_location_fsx_windows(
         self, LocationArn: str
     ) -> DescribeLocationFsxWindowsResponseTypeDef:
         """
-        [Client.describe_location_fsx_windows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
+        [Client.describe_location_fsx_windows documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
         """
 
     def describe_location_nfs(self, LocationArn: str) -> DescribeLocationNfsResponseTypeDef:
         """
-        [Client.describe_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
+        [Client.describe_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
         """
 
     def describe_location_object_storage(
         self, LocationArn: str
     ) -> DescribeLocationObjectStorageResponseTypeDef:
         """
-        [Client.describe_location_object_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
+        [Client.describe_location_object_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
         """
 
     def describe_location_s3(self, LocationArn: str) -> DescribeLocationS3ResponseTypeDef:
         """
-        [Client.describe_location_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_location_s3)
+        [Client.describe_location_s3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_location_s3)
         """
 
     def describe_location_smb(self, LocationArn: str) -> DescribeLocationSmbResponseTypeDef:
         """
-        [Client.describe_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_location_smb)
+        [Client.describe_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_location_smb)
         """
 
     def describe_task(self, TaskArn: str) -> DescribeTaskResponseTypeDef:
         """
-        [Client.describe_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_task)
+        [Client.describe_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_task)
         """
 
     def describe_task_execution(
         self, TaskExecutionArn: str
     ) -> DescribeTaskExecutionResponseTypeDef:
         """
-        [Client.describe_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.describe_task_execution)
+        [Client.describe_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.describe_task_execution)
         """
 
     def generate_presigned_url(
@@ -291,14 +285,14 @@ class DataSyncClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
         """
 
     def list_agents(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListAgentsResponseTypeDef:
         """
-        [Client.list_agents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.list_agents)
+        [Client.list_agents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.list_agents)
         """
 
     def list_locations(
@@ -308,28 +302,28 @@ class DataSyncClient:
         Filters: List[LocationFilterTypeDef] = None,
     ) -> ListLocationsResponseTypeDef:
         """
-        [Client.list_locations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.list_locations)
+        [Client.list_locations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.list_locations)
         """
 
     def list_tags_for_resource(
         self, ResourceArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
         """
 
     def list_task_executions(
         self, TaskArn: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListTaskExecutionsResponseTypeDef:
         """
-        [Client.list_task_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.list_task_executions)
+        [Client.list_task_executions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.list_task_executions)
         """
 
     def list_tasks(
         self, MaxResults: int = None, NextToken: str = None, Filters: List[TaskFilterTypeDef] = None
     ) -> ListTasksResponseTypeDef:
         """
-        [Client.list_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.list_tasks)
+        [Client.list_tasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.list_tasks)
         """
 
     def start_task_execution(
@@ -339,22 +333,22 @@ class DataSyncClient:
         Includes: List["FilterRuleTypeDef"] = None,
     ) -> StartTaskExecutionResponseTypeDef:
         """
-        [Client.start_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.start_task_execution)
+        [Client.start_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.start_task_execution)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagListEntryTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, Keys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.untag_resource)
         """
 
     def update_agent(self, AgentArn: str, Name: str = None) -> Dict[str, Any]:
         """
-        [Client.update_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.update_agent)
+        [Client.update_agent documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.update_agent)
         """
 
     def update_location_nfs(
@@ -365,21 +359,21 @@ class DataSyncClient:
         MountOptions: "NfsMountOptionsTypeDef" = None,
     ) -> Dict[str, Any]:
         """
-        [Client.update_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.update_location_nfs)
+        [Client.update_location_nfs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.update_location_nfs)
         """
 
     def update_location_object_storage(
         self,
         LocationArn: str,
         ServerPort: int = None,
-        ServerProtocol: Literal["HTTPS", "HTTP"] = None,
+        ServerProtocol: ObjectStorageServerProtocol = None,
         Subdirectory: str = None,
         AccessKey: str = None,
         SecretKey: str = None,
         AgentArns: List[str] = None,
     ) -> Dict[str, Any]:
         """
-        [Client.update_location_object_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
+        [Client.update_location_object_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
         """
 
     def update_location_smb(
@@ -393,7 +387,7 @@ class DataSyncClient:
         MountOptions: "SmbMountOptionsTypeDef" = None,
     ) -> Dict[str, Any]:
         """
-        [Client.update_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.update_location_smb)
+        [Client.update_location_smb documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.update_location_smb)
         """
 
     def update_task(
@@ -406,46 +400,46 @@ class DataSyncClient:
         CloudWatchLogGroupArn: str = None,
     ) -> Dict[str, Any]:
         """
-        [Client.update_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.update_task)
+        [Client.update_task documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.update_task)
         """
 
     def update_task_execution(
         self, TaskExecutionArn: str, Options: "OptionsTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Client.update_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Client.update_task_execution)
+        [Client.update_task_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Client.update_task_execution)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_agents"]) -> ListAgentsPaginator:
+    def get_paginator(self, operation_name: ListAgentsPaginatorName) -> ListAgentsPaginator:
         """
-        [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+        [Paginator.ListAgents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListAgents)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_locations"]) -> ListLocationsPaginator:
+    def get_paginator(self, operation_name: ListLocationsPaginatorName) -> ListLocationsPaginator:
         """
-        [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+        [Paginator.ListLocations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListLocations)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_tags_for_resource"]
+        self, operation_name: ListTagsForResourcePaginatorName
     ) -> ListTagsForResourcePaginator:
         """
-        [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+        [Paginator.ListTagsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_task_executions"]
+        self, operation_name: ListTaskExecutionsPaginatorName
     ) -> ListTaskExecutionsPaginator:
         """
-        [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+        [Paginator.ListTaskExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_tasks"]) -> ListTasksPaginator:
+    def get_paginator(self, operation_name: ListTasksPaginatorName) -> ListTasksPaginator:
         """
-        [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+        [Paginator.ListTasks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/datasync.html#DataSync.Paginator.ListTasks)
         """
