@@ -13,10 +13,34 @@ import sys
 from datetime import datetime
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_datasync.literals import (
+    AgentStatus,
+    Atime,
+    EndpointType,
+    FilterType,
+    Gid,
+    LocationFilterName,
+    LogLevel,
+    Mtime,
+    NfsVersion,
+    ObjectStorageServerProtocol,
+    Operator,
+    OverwriteMode,
+    PhaseStatus,
+    PosixPermissions,
+    PreserveDeletedFiles,
+    PreserveDevices,
+    S3StorageClass,
+    SmbVersion,
+    TaskExecutionStatus,
+    TaskFilterName,
+    TaskQueueing,
+    TaskStatus,
+    TransferMode,
+    Uid,
+    VerifyMode,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -68,45 +92,39 @@ __all__ = (
 )
 
 AgentListEntryTypeDef = TypedDict(
-    "AgentListEntryTypeDef",
-    {"AgentArn": str, "Name": str, "Status": Literal["ONLINE", "OFFLINE"]},
-    total=False,
+    "AgentListEntryTypeDef", {"AgentArn": str, "Name": str, "Status": AgentStatus}, total=False
 )
 
 Ec2ConfigTypeDef = TypedDict("Ec2ConfigTypeDef", {"SubnetArn": str, "SecurityGroupArns": List[str]})
 
 FilterRuleTypeDef = TypedDict(
-    "FilterRuleTypeDef", {"FilterType": Literal["SIMPLE_PATTERN"], "Value": str}, total=False
+    "FilterRuleTypeDef", {"FilterType": FilterType, "Value": str}, total=False
 )
 
 LocationListEntryTypeDef = TypedDict(
     "LocationListEntryTypeDef", {"LocationArn": str, "LocationUri": str}, total=False
 )
 
-NfsMountOptionsTypeDef = TypedDict(
-    "NfsMountOptionsTypeDef",
-    {"Version": Literal["AUTOMATIC", "NFS3", "NFS4_0", "NFS4_1"]},
-    total=False,
-)
+NfsMountOptionsTypeDef = TypedDict("NfsMountOptionsTypeDef", {"Version": NfsVersion}, total=False)
 
 OnPremConfigTypeDef = TypedDict("OnPremConfigTypeDef", {"AgentArns": List[str]})
 
 OptionsTypeDef = TypedDict(
     "OptionsTypeDef",
     {
-        "VerifyMode": Literal["POINT_IN_TIME_CONSISTENT", "ONLY_FILES_TRANSFERRED", "NONE"],
-        "OverwriteMode": Literal["ALWAYS", "NEVER"],
-        "Atime": Literal["NONE", "BEST_EFFORT"],
-        "Mtime": Literal["NONE", "PRESERVE"],
-        "Uid": Literal["NONE", "INT_VALUE", "NAME", "BOTH"],
-        "Gid": Literal["NONE", "INT_VALUE", "NAME", "BOTH"],
-        "PreserveDeletedFiles": Literal["PRESERVE", "REMOVE"],
-        "PreserveDevices": Literal["NONE", "PRESERVE"],
-        "PosixPermissions": Literal["NONE", "PRESERVE"],
+        "VerifyMode": VerifyMode,
+        "OverwriteMode": OverwriteMode,
+        "Atime": Atime,
+        "Mtime": Mtime,
+        "Uid": Uid,
+        "Gid": Gid,
+        "PreserveDeletedFiles": PreserveDeletedFiles,
+        "PreserveDevices": PreserveDevices,
+        "PosixPermissions": PosixPermissions,
         "BytesPerSecond": int,
-        "TaskQueueing": Literal["ENABLED", "DISABLED"],
-        "LogLevel": Literal["OFF", "BASIC", "TRANSFER"],
-        "TransferMode": Literal["CHANGED", "ALL"],
+        "TaskQueueing": TaskQueueing,
+        "LogLevel": LogLevel,
+        "TransferMode": TransferMode,
     },
     total=False,
 )
@@ -124,9 +142,7 @@ PrivateLinkConfigTypeDef = TypedDict(
 
 S3ConfigTypeDef = TypedDict("S3ConfigTypeDef", {"BucketAccessRoleArn": str})
 
-SmbMountOptionsTypeDef = TypedDict(
-    "SmbMountOptionsTypeDef", {"Version": Literal["AUTOMATIC", "SMB2", "SMB3"]}, total=False
-)
+SmbMountOptionsTypeDef = TypedDict("SmbMountOptionsTypeDef", {"Version": SmbVersion}, total=False)
 
 _RequiredTagListEntryTypeDef = TypedDict("_RequiredTagListEntryTypeDef", {"Key": str})
 _OptionalTagListEntryTypeDef = TypedDict(
@@ -140,12 +156,7 @@ class TagListEntryTypeDef(_RequiredTagListEntryTypeDef, _OptionalTagListEntryTyp
 
 TaskExecutionListEntryTypeDef = TypedDict(
     "TaskExecutionListEntryTypeDef",
-    {
-        "TaskExecutionArn": str,
-        "Status": Literal[
-            "QUEUED", "LAUNCHING", "PREPARING", "TRANSFERRING", "VERIFYING", "SUCCESS", "ERROR"
-        ],
-    },
+    {"TaskExecutionArn": str, "Status": TaskExecutionStatus},
     total=False,
 )
 
@@ -153,12 +164,12 @@ TaskExecutionResultDetailTypeDef = TypedDict(
     "TaskExecutionResultDetailTypeDef",
     {
         "PrepareDuration": int,
-        "PrepareStatus": Literal["PENDING", "SUCCESS", "ERROR"],
+        "PrepareStatus": PhaseStatus,
         "TotalDuration": int,
         "TransferDuration": int,
-        "TransferStatus": Literal["PENDING", "SUCCESS", "ERROR"],
+        "TransferStatus": PhaseStatus,
         "VerifyDuration": int,
-        "VerifyStatus": Literal["PENDING", "SUCCESS", "ERROR"],
+        "VerifyStatus": PhaseStatus,
         "ErrorCode": str,
         "ErrorDetail": str,
     },
@@ -166,13 +177,7 @@ TaskExecutionResultDetailTypeDef = TypedDict(
 )
 
 TaskListEntryTypeDef = TypedDict(
-    "TaskListEntryTypeDef",
-    {
-        "TaskArn": str,
-        "Status": Literal["AVAILABLE", "CREATING", "QUEUED", "RUNNING", "UNAVAILABLE"],
-        "Name": str,
-    },
-    total=False,
+    "TaskListEntryTypeDef", {"TaskArn": str, "Status": TaskStatus, "Name": str}, total=False
 )
 
 TaskScheduleTypeDef = TypedDict("TaskScheduleTypeDef", {"ScheduleExpression": str})
@@ -210,10 +215,10 @@ DescribeAgentResponseTypeDef = TypedDict(
     {
         "AgentArn": str,
         "Name": str,
-        "Status": Literal["ONLINE", "OFFLINE"],
+        "Status": AgentStatus,
         "LastConnectionTime": datetime,
         "CreationTime": datetime,
-        "EndpointType": Literal["PUBLIC", "PRIVATE_LINK", "FIPS"],
+        "EndpointType": EndpointType,
         "PrivateLinkConfig": "PrivateLinkConfigTypeDef",
     },
     total=False,
@@ -262,7 +267,7 @@ DescribeLocationObjectStorageResponseTypeDef = TypedDict(
         "LocationUri": str,
         "AccessKey": str,
         "ServerPort": int,
-        "ServerProtocol": Literal["HTTPS", "HTTP"],
+        "ServerProtocol": ObjectStorageServerProtocol,
         "AgentArns": List[str],
         "CreationTime": datetime,
     },
@@ -274,15 +279,7 @@ DescribeLocationS3ResponseTypeDef = TypedDict(
     {
         "LocationArn": str,
         "LocationUri": str,
-        "S3StorageClass": Literal[
-            "STANDARD",
-            "STANDARD_IA",
-            "ONEZONE_IA",
-            "INTELLIGENT_TIERING",
-            "GLACIER",
-            "DEEP_ARCHIVE",
-            "OUTPOSTS",
-        ],
+        "S3StorageClass": S3StorageClass,
         "S3Config": "S3ConfigTypeDef",
         "AgentArns": List[str],
         "CreationTime": datetime,
@@ -308,9 +305,7 @@ DescribeTaskExecutionResponseTypeDef = TypedDict(
     "DescribeTaskExecutionResponseTypeDef",
     {
         "TaskExecutionArn": str,
-        "Status": Literal[
-            "QUEUED", "LAUNCHING", "PREPARING", "TRANSFERRING", "VERIFYING", "SUCCESS", "ERROR"
-        ],
+        "Status": TaskExecutionStatus,
         "Options": "OptionsTypeDef",
         "Excludes": List["FilterRuleTypeDef"],
         "Includes": List["FilterRuleTypeDef"],
@@ -329,7 +324,7 @@ DescribeTaskResponseTypeDef = TypedDict(
     "DescribeTaskResponseTypeDef",
     {
         "TaskArn": str,
-        "Status": Literal["AVAILABLE", "CREATING", "QUEUED", "RUNNING", "UNAVAILABLE"],
+        "Status": TaskStatus,
         "Name": str,
         "CurrentTaskExecutionArn": str,
         "SourceLocationArn": str,
@@ -378,23 +373,7 @@ ListTasksResponseTypeDef = TypedDict(
 )
 
 LocationFilterTypeDef = TypedDict(
-    "LocationFilterTypeDef",
-    {
-        "Name": Literal["LocationUri", "LocationType", "CreationTime"],
-        "Values": List[str],
-        "Operator": Literal[
-            "Equals",
-            "NotEquals",
-            "In",
-            "LessThanOrEqual",
-            "LessThan",
-            "GreaterThanOrEqual",
-            "GreaterThan",
-            "Contains",
-            "NotContains",
-            "BeginsWith",
-        ],
-    },
+    "LocationFilterTypeDef", {"Name": LocationFilterName, "Values": List[str], "Operator": Operator}
 )
 
 PaginatorConfigTypeDef = TypedDict(
@@ -406,21 +385,5 @@ StartTaskExecutionResponseTypeDef = TypedDict(
 )
 
 TaskFilterTypeDef = TypedDict(
-    "TaskFilterTypeDef",
-    {
-        "Name": Literal["LocationId", "CreationTime"],
-        "Values": List[str],
-        "Operator": Literal[
-            "Equals",
-            "NotEquals",
-            "In",
-            "LessThanOrEqual",
-            "LessThan",
-            "GreaterThanOrEqual",
-            "GreaterThan",
-            "Contains",
-            "NotContains",
-            "BeginsWith",
-        ],
-    },
+    "TaskFilterTypeDef", {"Name": TaskFilterName, "Values": List[str], "Operator": Operator}
 )
